@@ -26,8 +26,8 @@
 #include "lib/latexresult.h"
 #include "lib/animationresult.h"
 
-#include <KGlobal>
 #include <QDir>
+#include <QStandardPaths>
 
 LoadedExpression::LoadedExpression( Cantor::Session* session ) : Cantor::Expression( session )
 {
